#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
# 
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
# 
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
# 
# 
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
# 
#  See LICENSE.txt
#  END LICENSE
#
import requests
from netbluemind.python import serder

from netbluemind.calendar.api.VEvent import VEvent
from netbluemind.calendar.api.VEvent import __VEventSerDer__
class VEventOccurrence (VEvent):
    def __init__( self):
        VEvent.__init__(self)
        self.recurid = None
        pass

class __VEventOccurrenceSerDer__:
    def __init__( self ):
        pass

    def parse(self, value):
        if(value == None):
            return None
        instance = VEventOccurrence()

        self.parseInternal(value, instance)
        return instance

    def parseInternal(self, value, instance):
        __VEventSerDer__().parseInternal(value,instance)
        from netbluemind.core.api.date.BmDateTime import BmDateTime
        from netbluemind.core.api.date.BmDateTime import __BmDateTimeSerDer__
        recuridValue = value['recurid']
        instance.recurid = __BmDateTimeSerDer__().parse(recuridValue)
        return instance

    def encode(self, value):
        if(value == None):
            return None
        instance = dict()
        self.encodeInternal(value,instance)
        return instance

    def encodeInternal(self, value, instance):
        __VEventSerDer__().encodeInternal(value,instance)

        from netbluemind.core.api.date.BmDateTime import BmDateTime
        from netbluemind.core.api.date.BmDateTime import __BmDateTimeSerDer__
        recuridValue = value.recurid
        instance["recurid"] = __BmDateTimeSerDer__().encode(recuridValue)
        return instance

